@@ -3,11 +3,17 @@ module Data.Maybe.HT where
 import Data.Maybe (fromMaybe, )
 import Control.Monad (msum, )
 
+{- $setup
+>>> import Control.Monad (guard)
+-}
+
 {-
 It was proposed as addition to Data.Maybe and rejected at that time.
 <http://www.haskell.org/pipermail/libraries/2004-July/002381.html>
 -}
-{- | Returns 'Just' if the precondition is fulfilled. -}
+{- | Returns 'Just' if the precondition is fulfilled.
+prop> \b x ->  (guard b >> x)  ==  (toMaybe b =<< (x::Maybe Char))
+-}
 {-# INLINE toMaybe #-}
 toMaybe :: Bool -> a -> Maybe a
 toMaybe False _ = Nothing
